#!/bin/bash
#SBATCH -n 1
#SBATCH -t 10-12:00:00
#SBATCH -J dlrstorap5_ele
#SBATCH --mem=12000
#SBATCH -o  /scratch/eexarcho/Eleftheria/Retrieve_ORAP5/dl_restarts-%j.log

set -exv
module load ECAC

DATASOURCE="ec:/RDX/prepIFS/g0tx" # Root of the path where to find ORAS4 on ECFS
YEARI=2000
YEARF=2013 # Last year to download
MEMBER_LST="0" # List of members to download
YEAR=$YEARI 


# Copy the files from ecmwf locally 

workdir=/scratch/Earth/eexarcho/ORAP5/
mkdir -p $workdir
cd $workdir

echo $YEAR
for year in `seq $YEARI $YEARF`; do
mkdir -p /esnas/reconstructions/ecmwf/orap5/restarts/$YEAR
  for mem in $MEMBER_LST ; do
    for file in $( ecaccess-file-dir ${DATASOURCE}/opa${mem}/restart/${YEAR}/g0tx_${YEAR}*_*_restart.tar.gz )
    do
      if [[ "$file" != "ECFS" ]];then
        echo $file
        if [[ ! -f /esnas/reconstructions/ecmwf/orap5/restarts/${YEAR}/$file ]]; then
          while [[ ! -f /esnas/reconstructions/ecmwf/orap5/restarts/${YEAR}/$file ]]
          do
            ecaccess-file-get -progress ${DATASOURCE}/opa${mem}/restart/${YEAR}/$file $file
            mv $file /esnas/reconstructions/ecmwf/orap5/restarts/${YEAR}/.
          done
        fi
      fi
    done
  done
  YEAR=$((YEAR+1))
done


# Copy the files to /esnas/releases

dir=/esnas/reconstructions/ecmwf/orap5/restarts/ 
outdir=/esnas/releases/ic/ocean/ORCA025L75/ORAP5
curdir=/scratch/eexarcho/Eleftheria/Copy_ORAP5

## We need to pick a date closest to the date of initializing (1st
## May/November) but this is not automatic because the set of dates is
## not the same in every year in  ORAP5, so, we need to manually check the
## available files for every year.  

# May start dates 
for year in {2000..2003} ; do 
	echo $year 
	dirin=${dir}/${year} 
	if [ -e $dirin  ] ; then   
		cd $dirin 
                for file in $( ls   g0tx_${year}0429* ) ; do 
			inname=$(echo $file | cut -f1 -d"." )
			ofile=ORAP5_fc0_${year}0430_restart.nc.gz
			if [ ! -e  ${outdir}/${ofile}  ]  ; then   
			cd $curdir 
			gunzip -c   ${dirin}/$file  >  ${inname}.tar  
			tar xfv ${inname}.tar  
			gzip -c ${inname}.nc >  ${outdir}/${ofile} 
			rm -rf  ${curdir}/g0tx*tar  ${curdir}/g0t*nc 
		fi 
	done 
	fi 



# November start dates 
	echo $year 
	dirin=${dir}/${year} 
	if [ -e $dirin  ] ; then   
		cd $dirin 
                for file in $( ls   g0tx_${year}1026* ) ; do 
			inname=$(echo $file | cut -f1 -d"." )
			ofile=ORAP5_fc0_${year}1031_restart.nc.gz
			if [ ! -e  ${outdir}/${ofile}  ]  ; then   
			cd $curdir 
			gunzip -c   ${dirin}/$file  >  ${inname}.tar  
			tar xfv ${inname}.tar  
			gzip -c ${inname}.nc >  ${outdir}/${ofile} 
			rm -rf  ${curdir}/g0tx*tar  ${curdir}/g0t*nc 
		fi 
	done 
	fi 
done 

